;; Generated package description from taxy.el  -*- no-byte-compile: t -*-
(define-package "taxy" "0.10.0.20220805.144002" "Programmable taxonomical grouping for arbitrary objects" '((emacs "26.3")) :commit "3c561ceaf967a827cb4f02db870a52c8e77d8db0" :authors '(("Adam Porter" . "adam@alphapapa.net")) :maintainer '("Adam Porter" . "adam@alphapapa.net") :keywords '("lisp") :url "https://github.com/alphapapa/taxy.el")
